==> openflowplugin-extension-nicira-0.9.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/nshc/_1/grouping/NxmNxNshc1.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nshc._1.grouping;
import java.lang.Class;
import java.lang.Long;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxNshc1Grouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-nshc-1 {
 *   leaf value {
 *     type uint32;
 *   }
 *   leaf mask {
 *     type uint32;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-nshc-1-grouping/nxm-nx-nshc-1</i>
 *
 * <p>To create instances of this class use {@link NxmNxNshc1Builder}.
 * @see NxmNxNshc1Builder
 *
 */
public interface NxmNxNshc1
    extends
    ChildOf<NxmNxNshc1Grouping>,
    Augmentable<NxmNxNshc1>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-nshc-1");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nshc._1.grouping.NxmNxNshc1> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nshc._1.grouping.NxmNxNshc1.class;
    }
    
    /**
     * @return <code>java.lang.Long</code> <code>value</code>, or <code>null</code> if not present
     */
    @Nullable Long getValue();
    
    /**
     * @return <code>java.lang.Long</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Long getMask();

}

==> openflowplugin-extension-nicira-0.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/nshc/_1/grouping/NxmNxNshc1.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nshc._1.grouping;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxNshc1Grouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-nshc-1 {
 *   leaf value {
 *     type uint32;
 *   }
 *   leaf mask {
 *     type uint32;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-nshc-1-grouping/nxm-nx-nshc-1</i>
 *
 * <p>To create instances of this class use {@link NxmNxNshc1Builder}.
 * @see NxmNxNshc1Builder
 *
 */
public interface NxmNxNshc1
    extends
    ChildOf<NxmNxNshc1Grouping>,
    Augmentable<NxmNxNshc1>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-nshc-1");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nshc._1.grouping.NxmNxNshc1> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nshc._1.grouping.NxmNxNshc1.class;
    }
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint32</code> <code>value</code>, or <code>null</code> if not present
     */
    @Nullable Uint32 getValue();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint32</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Uint32 getMask();

}
